@@ -9,15 +9,19 @@ P  -   Safer, friendlier printf/print/sprintf + say
 
 =head1 VERSION
 
-Version  "1.1.27"
+Version  "1.1.28"
 
 =cut
 
 { package P;
 	use warnings; use strict;use mem;
-	our $VERSION='1.1.27';
+	our $VERSION='1.1.28';
 
 # RCS $Revision: 1.44 $ -  $Date: 2015-05-20 00:43:36-07 $
+# 1.1.28	- testsuite fix - unknown failure case in sprintf:
+#           "Redundant argument in sprintf "... for "return sprintf $fmt, $v";
+#           Trying parens around sprintf($fmt, $v);
+#           (shot in dark for strawberry win32 perl on win10...)
 # 1.1.27	- test fix -- Makefile.PL improperly specified "test", rather
 #           rather than using t/*.*t as pattern
 # 1.1.26  - add code to allow changing defaults for literals and run-time 
@@ -301,7 +305,7 @@ IGN
 										sub ($$) { 1																&& q{"%s"}} ];
 
 			do { $fmt = $_->($v, $ro) and last } for @$given;
-			return sprintf $fmt, $v;
+			return sprintf($fmt, $v);
 		} else { 
 			my $pkg = '';
 			($pkg, $ref) = ($1, $2) if 0 <= (index $v,'=') && $v=~m{([\w:]+)=(\w+)}; 
